"use strict";(self.webpackChunkAutoGen_Assistant=self.webpackChunkAutoGen_Assistant||[]).push([[218],{2513:function(e,t,n){n.r(t);var l=n(7294),o=n(1082);const a={color:"#232129",padding:"96px",fontFamily:"-apple-system, Roboto, sans-serif, serif"},r={marginTop:0,marginBottom:64,maxWidth:320},s={marginBottom:48};t.default=()=>l.createElement("main",{style:a},l.createElement("title",null,"Not found"),l.createElement("h1",{style:r},"Page not found"),l.createElement("p",{style:s},"Sorry"," ",l.createElement("span",{role:"img","aria-label":"Pensive emoji"},"😔")," ","we couldn’t find what you were looking for.",l.createElement("br",null),null,l.createElement("br",null),l.createElement(o.Link,{to:"/"},"Go home"),"."))}}]);
//# sourceMappingURL=component---src-pages-404-tsx-8b0e5c8b3925c8b5fa58.js.map